@@ -1,19 +1,19 @@
 extern crate basic_dsp;
-extern crate rand;
 extern crate num;
+extern crate rand;
 pub mod tools;
 
 mod conv_test {
-    use basic_dsp::*;
     use basic_dsp::conv_types::*;
+    use basic_dsp::*;
     use tools::*;
-    
+
     #[test]
     fn compare_conv_freq_multiplication_for_rc() {
         for iteration in 0..3 {
             let a = create_data_even(201602211, iteration, 1001, 2000);
             let delta = create_delta(201602212, iteration);
-            let mut time = a.to_complex_time_vec();
+            let mut time = a.to_complex_time_vec_par();
             time.set_delta(delta);
             let fun: RaisedCosineFunction<f32> = RaisedCosineFunction::new(0.35);
             let mut buffer = SingleBuffer::new();
@@ -21,17 +21,21 @@ mod conv_test {
             let points = time.points();
             // Should get us a range [0.0 .. 1.0] and hopefully we are not that unlucky to get 0.0
             let ratio = create_delta(20160229, iteration).abs() / 10.0;
-            time.convolve(&mut buffer,
-                          &fun as &RealImpulseResponse<f32>,
-                          ratio,
-                          points);
+            time.convolve(
+                &mut buffer,
+                &fun as &RealImpulseResponse<f32>,
+                ratio,
+                points,
+            );
             freq.multiply_frequency_response(&fun as &RealFrequencyResponse<f32>, 1.0 / ratio);
             let ifreq_res = freq.ifft(&mut buffer);
-            assert_vector_eq_with_reason_and_tolerance(&ifreq_res[..],
-                                                       &time[..],
-                                                       0.2,
-                                                       "Results should match independent if done \
-                                                        in time or frequency domain");
+            assert_vector_eq_with_reason_and_tolerance(
+                &ifreq_res[..],
+                &time[..],
+                0.2,
+                "Results should match independent if done \
+                 in time or frequency domain",
+            );
         }
     }
 
@@ -40,7 +44,7 @@ mod conv_test {
         for iteration in 0..3 {
             let a = create_data_even(201602214, iteration, 2001, 4000);
             let delta = create_delta(201602215, iteration);
-            let mut time = a.to_complex_time_vec();
+            let mut time = a.to_complex_time_vec_par();
             time.set_delta(delta);
             let fun: SincFunction<f32> = SincFunction::new();
             let mut buffer = SingleBuffer::new();
@@ -48,17 +52,21 @@ mod conv_test {
             let points = time.points();
             // Should get us a range [0.5 .. 1.0]
             let ratio = create_delta(201602216, iteration).abs() / 20.0 + 0.5;
-            time.convolve(&mut buffer,
-                          &fun as &RealImpulseResponse<f32>,
-                          ratio,
-                          points);
+            time.convolve(
+                &mut buffer,
+                &fun as &RealImpulseResponse<f32>,
+                ratio,
+                points,
+            );
             freq.multiply_frequency_response(&fun as &RealFrequencyResponse<f32>, 1.0 / ratio);
             let ifreq_res = freq.ifft(&mut buffer);
-            assert_vector_eq_with_reason_and_tolerance(&ifreq_res[..],
-                                                       &time[..],
-                                                       0.3,
-                                                       "Results should match independent if done \
-                                                        in time or frequency domain");
+            assert_vector_eq_with_reason_and_tolerance(
+                &ifreq_res[..],
+                &time[..],
+                0.3,
+                "Results should match independent if done \
+                 in time or frequency domain",
+            );
         }
     }
 
@@ -74,25 +82,31 @@ mod conv_test {
             let a = create_data_even(201602217, iteration, 2002, 4000);
             let b = create_data_even(201602218, iteration, 50, 202);
             let delta = create_delta(201602219, iteration);
-            let mut time = a.to_complex_time_vec();
+            let mut time = a.to_complex_time_vec_par();
             time.set_delta(delta);
             let mut buffer = SingleBuffer::new();
             let fun: RaisedCosineFunction<f32> = RaisedCosineFunction::new(0.35);
             let ratio = iteration as f32 + 1.0;
             let mut left = time.clone();
-            left.convolve(&mut buffer,
-                          &fun as &RealImpulseResponse<f32>,
-                          ratio,
-                          b.len());
-            time.convolve(&mut buffer,
-                          &fun as &RealImpulseResponse<f32>,
-                          ratio + offset,
-                          b.len());
-            assert_vector_eq_with_reason_and_tolerance(&left[..],
-                                                       &time[..],
-                                                       0.1,
-                                                       "Results should match independent if done \
-                                                        in optimized or non optimized code branch");
+            left.convolve(
+                &mut buffer,
+                &fun as &RealImpulseResponse<f32>,
+                ratio,
+                b.len(),
+            );
+            time.convolve(
+                &mut buffer,
+                &fun as &RealImpulseResponse<f32>,
+                ratio + offset,
+                b.len(),
+            );
+            assert_vector_eq_with_reason_and_tolerance(
+                &left[..],
+                &time[..],
+                0.1,
+                "Results should match independent if done \
+                 in optimized or non optimized code branch",
+            );
         }
     }
 
@@ -102,9 +116,9 @@ mod conv_test {
             let a = create_data_even(201601171, iteration, 502, 2000);
             let b = create_data_with_len(201601172, iteration, a.len());
             let delta = create_delta(201601173, iteration);
-            let mut time1 = a.to_complex_time_vec();
+            let mut time1 = a.to_complex_time_vec_par();
             time1.set_delta(delta);
-            let mut time2 = b.to_complex_time_vec();
+            let mut time2 = b.to_complex_time_vec_par();
             time2.set_delta(delta);
             let mut buffer = SingleBuffer::new();
             let mut left = time1.clone();
@@ -113,11 +127,13 @@ mod conv_test {
             let freq2 = time2.fft(&mut buffer);
             freq1.mul(&freq2).unwrap();
             let right = freq1.ifft(&mut buffer);
-            assert_vector_eq_with_reason_and_tolerance(&left[..],
-                                                       &conv_swap(&right[..])[0..left.len()],
-                                                       0.2,
-                                                       "Results should match independent if done \
-                                                        in time or frequency domain");
+            assert_vector_eq_with_reason_and_tolerance(
+                &left[..],
+                &conv_swap(&right[..])[0..left.len()],
+                0.2,
+                "Results should match independent if done \
+                 in time or frequency domain",
+            );
         }
     }
 
@@ -126,9 +142,9 @@ mod conv_test {
         let a = create_data_even(201601171, 1, 18000, 20000);
         let b = create_data_with_len(201601172, 1, a.len());
         let delta = create_delta(201601173, 1);
-        let mut time1 = a.to_complex_time_vec();
+        let mut time1 = a.to_complex_time_vec_par();
         time1.set_delta(delta);
-        let mut time2 = b.to_complex_time_vec();
+        let mut time2 = b.to_complex_time_vec_par();
         time2.set_delta(delta);
         let mut buffer = SingleBuffer::new();
         let mut left = time1.clone();
@@ -137,11 +153,13 @@ mod conv_test {
         let freq2 = time2.fft(&mut buffer);
         freq1.mul(&freq2).unwrap();
         let right = freq1.ifft(&mut buffer);
-        assert_vector_eq_with_reason_and_tolerance(&left[..],
-                                                   &conv_swap(&right[..])[0..left.len()],
-                                                   0.2,
-                                                   "Results should match independent if done \
-                                                    in time or frequency domain");
+        assert_vector_eq_with_reason_and_tolerance(
+            &left[..],
+            &conv_swap(&right[..])[0..left.len()],
+            0.2,
+            "Results should match independent if done \
+             in time or frequency domain",
+        );
     }
 
     #[test]
@@ -150,22 +168,24 @@ mod conv_test {
             let a = create_data_even(201601174, iteration, 1002, 2000);
             let b = create_data_even(201601175, iteration, 50, 202);
             let delta = create_delta(201601176, iteration);
-            let mut time1 = a.to_complex_time_vec();
+            let mut time1 = a.to_complex_time_vec_par();
             time1.set_delta(delta);
-            let mut time2 = b.clone().to_complex_time_vec();
+            let mut time2 = b.clone().to_complex_time_vec_par();
             time2.set_delta(delta);
             let mut buffer = SingleBuffer::new();
             let mut left = time1.clone();
             left.convolve_signal(&mut buffer, &time2).unwrap();
-            let mut time2 = conv_zero_pad(&b, time1.len(), true).to_complex_time_vec();
+            let mut time2 = conv_zero_pad(&b, time1.len(), true).to_complex_time_vec_par();
             time2.set_delta(delta);
             time1.convolve_signal(&mut buffer, &time2).unwrap();
-            assert_vector_eq_with_reason_and_tolerance(&left[..],
-                                                       &time1[..],
-                                                       0.2,
-                                                       "Results should match independent if done \
-                                                        with a smaller vector or with a zero \
-                                                        padded vector of the same size");
+            assert_vector_eq_with_reason_and_tolerance(
+                &left[..],
+                &time1[..],
+                0.2,
+                "Results should match independent if done \
+                 with a smaller vector or with a zero \
+                 padded vector of the same size",
+            );
         }
     }
 
@@ -175,22 +195,24 @@ mod conv_test {
             let a = create_data_even(201601177, iteration, 1002, 2000);
             let b = create_data_even(201601178, iteration, 50, 202);
             let delta = create_delta(201601179, iteration);
-            let mut time1 = a.to_real_time_vec();
+            let mut time1 = a.to_real_time_vec_par();
             time1.set_delta(delta);
-            let mut time2 = b.clone().to_real_time_vec();
+            let mut time2 = b.clone().to_real_time_vec_par();
             time2.set_delta(delta);
             let mut buffer = SingleBuffer::new();
             let mut left = time1.clone();
             left.convolve_signal(&mut buffer, &time2).unwrap();
-            let mut time2 = conv_zero_pad(&b, time1.len(), false).to_real_time_vec();
+            let mut time2 = conv_zero_pad(&b, time1.len(), false).to_real_time_vec_par();
             time2.set_delta(delta);
             time1.convolve_signal(&mut buffer, &time2).unwrap();
-            assert_vector_eq_with_reason_and_tolerance(&left[..],
-                                                       &time1[..],
-                                                       0.2,
-                                                       "Results should match independent if done \
-                                                        with a smaller vector or with a zero \
-                                                        padded vector of the same size");
+            assert_vector_eq_with_reason_and_tolerance(
+                &left[..],
+                &time1[..],
+                0.2,
+                "Results should match independent if done \
+                 with a smaller vector or with a zero \
+                 padded vector of the same size",
+            );
         }
     }
 
