@@ -1,22 +1,25 @@
-use rand::*;
-use basic_dsp::*;
 use basic_dsp::numbers::*;
-use std::ops::Range;
+use basic_dsp::*;
 use num::complex::Complex32;
+use rand::*;
+use std::fmt::{Debug, Display};
+use std::ops::Range;
 use std::panic;
-use std::fmt::{Display, Debug};
 
 pub fn assert_vector_eq_with_reason<T>(left: &[T], right: &[T], reason: &str)
-    where T: RealNumber + Debug + Display
+where
+    T: RealNumber + Debug + Display,
 {
     assert_vector_eq_with_reason_and_tolerance(left, right, T::from(1e-6).unwrap(), reason);
 }
 
-pub fn assert_vector_eq_with_reason_and_tolerance<T>(left: &[T],
-                                                     right: &[T],
-                                                     tolerance: T,
-                                                     reason: &str)
-    where T: RealNumber + Debug + Display
+pub fn assert_vector_eq_with_reason_and_tolerance<T>(
+    left: &[T],
+    right: &[T],
+    tolerance: T,
+    reason: &str,
+) where
+    T: RealNumber + Debug + Display,
 {
     let mut errors = Vec::new();
     if reason.len() > 0 {
@@ -38,20 +41,21 @@ pub fn assert_vector_eq_with_reason_and_tolerance<T>(left: &[T],
         if (left[i] - right[i]).abs() > tolerance {
             differences += 1;
             if differences <= 10 {
-                errors.push(format!("Difference {} at index {}, left: {} != right: {}",
-                                    differences,
-                                    i,
-                                    left[i],
-                                    right[i]));
+                errors.push(format!(
+                    "Difference {} at index {}, left: {} != right: {}",
+                    differences, i, left[i], right[i]
+                ));
             }
         }
     }
 
     if differences > 0 {
-        errors.push(format!("Total number of differences: {}/{}={}%",
-                            differences,
-                            len,
-                            differences * 100 / len));
+        errors.push(format!(
+            "Total number of differences: {}/{}={}%",
+            differences,
+            len,
+            differences * 100 / len
+        ));
     }
 
     if differences > 0 || size_assert_failed {
@@ -63,7 +67,8 @@ pub fn assert_vector_eq_with_reason_and_tolerance<T>(left: &[T],
 }
 
 pub fn assert_vector_eq<T>(left: &[T], right: &[T])
-    where T: RealNumber + Debug + Display
+where
+    T: RealNumber + Debug + Display,
 {
     assert_vector_eq_with_reason(left, right, "");
 }
@@ -140,13 +145,14 @@ pub fn create_data_with_len64(seed: usize, iteration: usize, len: usize) -> Vec<
     data
 }
 
-pub fn create_data_even_in_range(seed: usize,
-                                 iteration: usize,
-                                 from: usize,
-                                 to: usize,
-                                 range_start: f32,
-                                 range_end: f32)
-                                 -> Vec<f32> {
+pub fn create_data_even_in_range(
+    seed: usize,
+    iteration: usize,
+    from: usize,
+    to: usize,
+    range_start: f32,
+    range_end: f32,
+) -> Vec<f32> {
     let len_seed: &[_] = &[seed, iteration];
     let mut rng: StdRng = SeedableRng::from_seed(len_seed);
     let len = rng.gen_range(from, to);
@@ -154,11 +160,12 @@ pub fn create_data_even_in_range(seed: usize,
     create_data_in_range_with_len(seed, iteration, len, range_start, range_end)
 }
 
-pub fn create_data_simd_len_in_range(seed: usize,
-                                     iteration: usize,
-                                     from: usize,
-                                     to: usize)
-                                     -> Vec<f32> {
+pub fn create_data_simd_len_in_range(
+    seed: usize,
+    iteration: usize,
+    from: usize,
+    to: usize,
+) -> Vec<f32> {
     let len_seed: &[_] = &[seed, iteration];
     let mut rng: StdRng = SeedableRng::from_seed(len_seed);
     let len = rng.gen_range(from, to);
@@ -167,12 +174,13 @@ pub fn create_data_simd_len_in_range(seed: usize,
     create_data_with_len(seed, iteration, len)
 }
 
-pub fn create_data_in_range_with_len(seed: usize,
-                                     iteration: usize,
-                                     len: usize,
-                                     range_start: f32,
-                                     range_end: f32)
-                                     -> Vec<f32> {
+pub fn create_data_in_range_with_len(
+    seed: usize,
+    iteration: usize,
+    len: usize,
+    range_start: f32,
+    range_end: f32,
+) -> Vec<f32> {
     let seed: &[_] = &[seed, iteration];
     let mut rng: StdRng = SeedableRng::from_seed(seed);
     let mut data = vec![0.0; len];
@@ -188,11 +196,13 @@ pub fn create_delta(seed: usize, iteration: usize) -> f32 {
     rng.gen_range(-10.0, 10.0)
 }
 
-pub fn create_random_multitones(seed: usize,
-                         iteration: usize,
-                         from: usize,
-                         to: usize,
-                         number_of_tones: usize) -> Vec<f32> {
+pub fn create_random_multitones(
+    seed: usize,
+    iteration: usize,
+    from: usize,
+    to: usize,
+    number_of_tones: usize,
+) -> Vec<f32> {
     let len_seed: &[_] = &[seed, iteration];
     let mut rng: StdRng = SeedableRng::from_seed(len_seed);
     let len = 2 * rng.gen_range(from, to);
@@ -224,7 +234,8 @@ pub const RANGE_MULTI_CORE: Range<usize> = Range {
 };
 
 pub fn parameterized_vector_test<F>(test_code: F)
-    where F: Fn(usize, Range<usize>) + Send + 'static + Sync
+where
+    F: Fn(usize, Range<usize>) + Send + 'static + Sync,
 {
     let mut test_errors = Vec::new();
 
@@ -251,20 +262,23 @@ pub fn parameterized_vector_test<F>(test_code: F)
             Ok(_) => (),
             Err(e) => {
                 if let Some(e) = e.downcast_ref::<&'static str>() {
-                    test_errors.push(format!("\nSingle threaded execution path failed on iteration \
-                                       {}\nFailure: {}",
-                                      iteration,
-                                      e));
+                    test_errors.push(format!(
+                        "\nSingle threaded execution path failed on iteration \
+                         {}\nFailure: {}",
+                        iteration, e
+                    ));
                 } else if let Some(e) = e.downcast_ref::<String>() {
-                    test_errors.push(format!("\nSingle threaded execution path failed on iteration \
-                                       {}\nFailure: {}",
-                                      iteration,
-                                      e));
+                    test_errors.push(format!(
+                        "\nSingle threaded execution path failed on iteration \
+                         {}\nFailure: {}",
+                        iteration, e
+                    ));
                 } else {
-                    test_errors.push(format!("\nSingle threaded execution path failed on iteration \
-                                       {}\nGot an unknown error: {:?}",
-                                      iteration,
-                                      e));
+                    test_errors.push(format!(
+                        "\nSingle threaded execution path failed on iteration \
+                         {}\nGot an unknown error: {:?}",
+                        iteration, e
+                    ));
                 }
             }
         }
@@ -289,20 +303,23 @@ pub fn parameterized_vector_test<F>(test_code: F)
             Ok(_) => (),
             Err(e) => {
                 if let Some(e) = e.downcast_ref::<&'static str>() {
-                    test_errors.push(format!("\nMulti threaded execution path failed on \
-                                              iteration {}\nFailure: {}",
-                                             iteration,
-                                             e));
+                    test_errors.push(format!(
+                        "\nMulti threaded execution path failed on \
+                         iteration {}\nFailure: {}",
+                        iteration, e
+                    ));
                 } else if let Some(e) = e.downcast_ref::<String>() {
-                    test_errors.push(format!("\nMulti threaded execution path failed on \
-                                              iteration {}\nFailure: {}",
-                                             iteration,
-                                             e));
+                    test_errors.push(format!(
+                        "\nMulti threaded execution path failed on \
+                         iteration {}\nFailure: {}",
+                        iteration, e
+                    ));
                 } else {
-                    test_errors.push(format!("\nMulti threaded execution path failed on \
-                                              iteration {}\nGot an unknown error: {:?}",
-                                             iteration,
-                                             e));
+                    test_errors.push(format!(
+                        "\nMulti threaded execution path failed on \
+                         iteration {}\nGot an unknown error: {:?}",
+                        iteration, e
+                    ));
                 }
             }
         }
